@@ -2,9 +2,8 @@
 
 __author__ = """Ralph Brecheisen"""
 __email__ = 'ralph.brecheisen@gmail.com'
-__version__ = '0.6.0'
+__version__ = '0.9.0'
 
-from .cnn import AutoSegL3CNN
-from .autosegl3 import AutoSegL3
+from .train.train import TrainL3
 from . import models
 from . import utils
